# JwksKeys

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**kty** | **str** | Key Type | [optional] 
**e** | **str** | Exponent Parameter | [optional] 
**n** | **str** | Modulus Parameter | [optional] 
**use** | **str** | Public Key Use Parameter | [optional] 
**alg** | **str** | Algorithm Parameter | [optional] 
**kid** | **str** | Key Id Header Parameter | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

